@@ -47,10 +47,12 @@ Rcpp::List vinecop_wrap(const Vinecop& vinecop_cpp) {
         pair_copulas[t] = tree_pcs;
     }
     double npars = vinecop_cpp.calculate_npars();
+    double threshold = vinecop_cpp.get_threshold();
     return Rcpp::List::create(
         Rcpp::Named("pair_copulas") = pair_copulas,
         Rcpp::Named("matrix") = matrix,
-        Rcpp::Named("npars") = npars
+        Rcpp::Named("npars") = npars,
+        Rcpp::Named("threshold") = threshold
     );
 }
 
